@@ -28,7 +28,7 @@ function weather_uk_save() {
     global $username,$data_dir;
     global $weather_weather_uk_visible;
 
-    if (isset($weather_weather_uk_visible)) {
+    if (sqgetGlobalVar('weather_weather_uk_visible', $vis, SQ_POST)) {
         setPref($data_dir, $username, 'weather_uk_visible', '1');
     } else {
         setPref($data_dir, $username, 'weather_uk_visible', '');
@@ -56,4 +56,4 @@ function weather_uk_options() {
 }
 
 
-?>
\ No newline at end of file
+?>
